==> camel-karavan-4.10.2.zip: camel-karavan-4.10.2/karavan-core/test/createKamelet.spec.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { expect } from 'chai';
import * as fs from 'fs';
import 'mocha';
import { CamelUtil } from '../src/core/api/CamelUtil';
import { KameletApi } from '../src/core/api/KameletApi';


describe('Create Kamelet', () => {

    it('Create new Kamelet from existing', () => {
        const kamelet = fs.readFileSync('test/timer-source.kamelet.yaml', { encoding: 'utf8', flag: 'r' });
        KameletApi.saveKamelets([kamelet]);
        const code = CamelUtil.createNewKameletCode("custom-timer-source.kamelet.yaml", 'source', "timer-source")
        console.log(code);
        // if (i.spec.flows) {
        //     expect(i.spec.flows[2].beans[0].name).to.equal('myNested');
        //     expect(i.spec.flows[2].beans[0].type).to.equal('${MyBean.class.name}');
        //     expect(i.spec.flows[2].beans[0].properties['nested.foo']).to.equal('valueFoo');
        //     expect(i.spec.flows[2].beans[1].name).to.equal('myProps');
        // }
    });
});

==> camel-karavan-4.14.2.zip: camel-karavan-4.14.2/karavan-core/test/createKamelet.spec.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { expect } from 'chai';
import * as fs from 'fs';
import 'mocha';
import { CamelUtil } from '../src/core/api/CamelUtil';
import { KameletApi } from '../src/core/api/KameletApi';


describe('Create Kamelet', () => {

    it('Create new Kamelet from existing', () => {
        const kamelet = fs.readFileSync('test/timer-source.kamelet.yaml', { encoding: 'utf8', flag: 'r' });
        KameletApi.saveCamelKamelets([kamelet]);
        const code = CamelUtil.createNewKameletCode("custom-timer-source.kamelet.yaml", 'source', "timer-source")
        console.log(code);
        // if (i.spec.flows) {
        //     expect(i.spec.flows[2].beans[0].name).to.equal('myNested');
        //     expect(i.spec.flows[2].beans[0].type).to.equal('${MyBean.class.name}');
        //     expect(i.spec.flows[2].beans[0].properties['nested.foo']).to.equal('valueFoo');
        //     expect(i.spec.flows[2].beans[1].name).to.equal('myProps');
        // }
    });
});
